name = "pyxem"
version = "0.15.0"
author = "Duncan Johnstone, Phillip Crout, Magnus Nord"
copyright = "Copyright 2016-2023, The pyxem developers"
# Contributors listed by original commiter, maintainers, then other
# within groups organised by  number of commits.
# See: https://github.com/pyxem/pyxem/graphs/contributors
credits = [
    "Duncan Johnstone",
    "Phillip Crout",
    "Magnus Nord",
    "Carter Francis",
    "Joonatan Laulainen",
    "Simon Høgås",
    "Eirik Opheim",
    "Ben Martineau",
    "Tina Bergh",
    "Eric Prestat",
    "Niels Cautaerts",
    "Stef Smeets",
    "Håkon Wiik Ånes",
    "Andrew Ross",
    "Joseph Broussard",
    "Sean Collins",
    "Tom Furnival",
    "Daen Jannis",
    "Ida Hjorth",
    "Shuoyuan Huang",
    "Endre Jacobsen",
    "Mohsen Danaie",
    "Andrew Herzing",
    "Tim Poon",
    "Tiarnan Doherty",
    "Jedrzej Morzy",
    "Affan Iqbal",
    "Tomas Ostasevicius",
    "Tor Inge Thorsen",
    "Matt von Lany",
    "Rob Tovey",
    "Sivert Dagenborg",
]
license = "GPLv3"
maintainer = "Duncan Johnstone, Phillip Crout, Magnus Nord, Carter Francis"
email = "pyxem.team@gmail.com"
status = "development"
